//////////////////////////////////////////
//  File is: HTBasicStrings.cpp
//////////////////////////////////////////

#include <stdio.h>
#include <string.h>
#include "HTBasicStrings.h"


//////////////////////////////////////////////////////////////////////////////////////////
//  HTBasic and C/C++ determine the length of strings differently.  C/C++ requires the string
//  to be terminated with a NULL character.  HTBasic stores the length of the string in the
//  two bytes right before the beginning of the string.  HTBasic will attempt to coordinate
//  these two methods as it passes a string parameter back and forth to a C/C++ dll.  However,
//  if the address of an array of strings is passed, the parameter fixing isn't aware of any elements
//  in the array after the first one.  These routines can help with that coordination from the
//  dll side.
//////////////////////////////////////////////////////////////////////////////////////////


/////////////////////////////////////////////////////////////////////////////////////
//  Make sure that a string that just came from HTBasic is NULL terminated so that
//  C/C++ routines can treat it properly.  The parameter is a pointer to the beginning of the
//  string.  The assumption is made that the length is stored in the two bytes just
//  before the beginning of the string.  This routine gets that length and puts a NULL
//  character in the appropriate spot.
void CheckStringFromHTBasic(char *pStringStart)
{
unsigned short *pStringLength;		// pointer to the length integer.

	pStringLength = (unsigned short *)(pStringStart - sizeof(unsigned short));	// get address of the length integer.

	pStringStart[*pStringLength] = '\0';	// put a NULL character at the end of the string

}	// CheckStringFromHTBasic


/////////////////////////////////////////////////////////////////////////////////////
//  Get a string ready to be passed back to HTBasic.  The parameter is a pointer to the
//  beginning of the string.  This routine checks the length of the string and stores it
//  in the two bytes just before the beginning of the string.
void ValidateStringForHTBasic(char *pStringStart)
{
unsigned short *pStringLength;		// pointer to the length character

	pStringLength = (unsigned short *)(pStringStart - sizeof(unsigned short));	// get address of the length integer.

	*pStringLength = strlen(pStringStart);	// store the length of the string in the length integer.

}	// ValidateStringForHTBasic